@@ -59,8 +59,8 @@ def display_jpg_image(image_to_display, image_size, tilechain_list):
     # resize image and ignore original aspect ratio
     img_resized = my_image.resize(image_size)
     # changing the file extension from jpg to png changes output brightness. You might need to play with this.
-    img_resized.save('./resized_image.png')
-    data = image.imread('./resized_image.png')
+    img_resized.save('./resized_image.jpg')
+    data = image.imread('./resized_image.jpg')
     target_tcs = []
     for row in data:
         temp_row = []
